@@ -1,6 +1,12 @@
-#' @importFrom parallel makeCluster stopCluster parSapply
+#' @importFrom BiocParallel bpvec
 .calculateSensitivitiesStar <-
-  function (pSets = list(), exps=NULL, cap=NA, na.rm=TRUE, area.type=c("Fitted","Actual"), nthread=1) {
+  function (tSets = list(), exps=NULL,
+            cap=NA, na.rm=TRUE, area.type=c("Fitted","Actual"), nthread=1) {
+
+    # Set multicore options
+    op <- options()
+    options(mc.cores=nthread)
+    on.exit(options(op))
 
     if (missing(area.type)) {
       area.type <- "Fitted"
@@ -8,8 +14,8 @@
     if (is.null(exps)) {
       stop("expriments is empty!")
     }
-    for (study in names(pSets)) {
-      pSets[[study]]@sensitivity$profiles$auc_recomputed_star <- NA
+    for (study in names(tSets)) {
+      sensitivityProfiles(tSets[[study]])$auc_recomputed_star <- NA
     }
     if (!is.na(cap)) {
       trunc <- TRUE
@@ -17,39 +23,45 @@
       trunc <- FALSE
     }
 
-    for(i in 1:nrow(exps)) {
+    for(i in seq_len(nrow(exps))) {
       ranges <- list()
-      for (study in names(pSets)) {
-        ranges[[study]] <- as.numeric(pSets[[study]]@sensitivity$raw[exps[i,study], ,"Dose"])
+      for (study in names(tSets)) {
+        ranges[[study]] <- as.numeric(sensitivityRaw(tSets[[study]])[exps[i,study], ,"Dose"])
       }
       ranges <- .getCommonConcentrationRange(ranges)
-      names(ranges) <- names(pSets)
-      for(study in names(pSets)) {
-        myx <- as.numeric(pSets[[study]]@sensitivity$raw[exps[i, study],,"Dose"]) %in% ranges[[study]]
-        pSets[[study]]@sensitivity$raw[exps[i,study],!myx, ] <- NA
+      names(ranges) <- names(tSets)
+      for(study in names(tSets)) {
+        myx <- as.numeric(sensitivityRaw(tSets[[study]])[exps[i, study],,"Dose"]) %in% ranges[[study]]
+        sensitivityRaw(tSets[[study]])[exps[i,study],!myx, ] <- NA
 
       }
     }
-    cl <- makeCluster(nthread)
-    for(study in names(pSets)){
+    for(study in names(tSets)){
 
-      auc_recomputed_star <- unlist(parSapply(cl=cl, rownames(pSets[[study]]@sensitivity$raw), function(experiment, exps, study, dataset, area.type){
+      auc_recomputed_star <- unlist(bpvec(rownames(sensitivityRaw(tSets[[study]])),
+                                          function(experiment, exps, study, dataset, area.type){
         if(!experiment %in% exps[,study]){return(NA_real_)}
         return(computeAUC(concentration=as.numeric(dataset[experiment,,1]),
                           viability=as.numeric(dataset[experiment,,2]),
                           trunc=trunc, conc_as_log=FALSE, viability_as_pct=TRUE, area.type=area.type)/100)
 
 
-      }, exps = exps, study = study, dataset = pSets[[study]]@sensitivity$raw, area.type=area.type))
+      }, exps = exps, study = study, dataset = sensitivityRaw(tSets[[study]]), area.type=area.type))
 
-      pSets[[study]]@sensitivity$profiles$auc_recomputed_star <- auc_recomputed_star
+      sensitivityProfiles(tSets[[study]])$auc_recomputed_star <- auc_recomputed_star
     }
-    stopCluster(cl)
-    return(pSets)
+    return(tSets)
   }
 
 ## This function computes AUC for the whole raw sensitivity data of a pset
-.calculateFromRaw <- function(raw.sensitivity, cap=NA, nthread=1, family=c("normal", "Cauchy"), scale = 0.07, n = 1){
+.calculateFromRaw <- function(raw.sensitivity, cap=NA, nthread=1,
+                              family=c("normal", "Cauchy"), scale = 0.07,
+                              n = 1) {
+  # Set multicore options
+  op <- options()
+  options(mc.cores=nthread)
+  on.exit(options(op))
+
   family <- match.arg(family)
 
   AUC <- vector(length=dim(raw.sensitivity)[1])
@@ -58,17 +70,14 @@
   IC50 <- vector(length=dim(raw.sensitivity)[1])
   names(IC50) <- dimnames(raw.sensitivity)[[1]]
 
-  #pars <- logLogisticRegression(raw.sensitivity[exp, , "Dose"], raw.sensitivity[exp, , "Viability"], conc_as_log=FALSE, viability_as_pct=TRUE, trunc=trunc)
-
   if (!is.na(cap)) {trunc <- TRUE}else{trunc <- FALSE}
 
-  if (nthread ==1){
+  if (nthread == 1){
     pars <- lapply(names(AUC), function(exp, raw.sensitivity, family, scale, n) {
       if(length(grep("///", raw.sensitivity[exp, , "Dose"])) > 0 | all(is.na(raw.sensitivity[exp, , "Dose"]))) {
         NA
       } else{
         logLogisticRegression(raw.sensitivity[exp, , "Dose"], raw.sensitivity[exp, , "Viability"], trunc=trunc, conc_as_log=FALSE, viability_as_pct=TRUE, family=family, scale=scale, median_n=n)
-        #computeAUC(concentration=raw.sensitivity[exp, , "Dose"], Hill_fit=Hill_fit, trunc=trunc, conc_as_log=FALSE, viability_as_pct=TRUE)
       }
     },raw.sensitivity=raw.sensitivity, family = family, scale = scale, n = n)
     names(pars) <- dimnames(raw.sensitivity)[[1]]
@@ -87,29 +96,28 @@
       }
     }, pars=pars))
   } else {
-    pars <- parallel::mclapply(names(AUC), function(exp, raw.sensitivity, family, scale, n, trunc) {
+    pars <- BiocParallel::bplapply(names(AUC), function(exp, raw.sensitivity, family, scale, n, trunc) {
       if(length(grep("///", raw.sensitivity[exp, , "Dose"])) > 0 | all(is.na(raw.sensitivity[exp, , "Dose"]))) {
         NA
       } else{
         logLogisticRegression(raw.sensitivity[exp, , "Dose"], raw.sensitivity[exp, , "Viability"], trunc=trunc, conc_as_log=FALSE, viability_as_pct=TRUE, family=family, scale=scale, median_n=n)
-        #computeAUC(concentration=raw.sensitivity[exp, , "Dose"], Hill_fit=Hill_fit, trunc=trunc, conc_as_log=FALSE, viability_as_pct=TRUE)
       }
-    },raw.sensitivity=raw.sensitivity, family = family, scale = scale, n = n, trunc = trunc, mc.cores = nthread)
+    },raw.sensitivity=raw.sensitivity, family = family, scale = scale, n = n, trunc = trunc)
     names(pars) <- dimnames(raw.sensitivity)[[1]]
-    AUC <- unlist(parallel::mclapply(names(pars), function(exp, raw.sensitivity, pars, trunc) {
+    AUC <- unlist(BiocParallel::bplapply(names(pars), function(exp, raw.sensitivity, pars, trunc) {
       if(any(is.na(pars[[exp]]))) {
         NA
       } else{
         computeAUC(concentration=raw.sensitivity[exp, , "Dose"], Hill_fit=pars[[exp]], trunc=trunc, conc_as_log=FALSE, viability_as_pct=TRUE)
       }
-    },raw.sensitivity=raw.sensitivity, pars=pars, trunc = trunc, mc.cores = nthread))
-    IC50 <- unlist(parallel::mclapply(names(pars), function(exp, pars, trunc) {
+    },raw.sensitivity=raw.sensitivity, pars=pars, trunc = trunc))
+    IC50 <- unlist(BiocParallel::bplapply(names(pars), function(exp, pars, trunc) {
       if(any(is.na(pars[[exp]]))) {
         NA
       } else{
         computeIC50(Hill_fit=pars[[exp]], trunc=trunc, conc_as_log=FALSE, viability_as_pct=TRUE)
       }
-    }, pars=pars, trunc = trunc, mc.cores = nthread))
+    }, pars=pars, trunc = trunc))
   }
 
   names(AUC) <- dimnames(raw.sensitivity)[[1]]
@@ -125,14 +133,14 @@
 {
   min.dose <- 0
   max.dose <- 10^100
-  for(i in 1:length(doses))
+  for(i in seq_along(doses))
   {
     min.dose <- max(min.dose, min(as.numeric(doses[[i]]), na.rm = TRUE), na.rm = TRUE)
     max.dose <- min(max.dose, max(as.numeric(doses[[i]]), na.rm = TRUE), na.rm = TRUE)
   }
 
   common.ranges <- list()
-  for(i in 1:length(doses))
+  for(i in seq_along(doses))
   {
     common.ranges[[i]] <- doses[[i]][
       which.min(abs(as.numeric(doses[[i]])-min.dose)):max(
@@ -147,14 +155,15 @@
 }
 
 ## calculate residual of fit
-.residual<-function(x, y, n, pars, scale = 0.07, family = c("normal", "Cauchy"), trunc = FALSE) {
+## FIXME:: Why is this different from CoreGx?
+## FIXME:: Is this the same as PharmacoGx?
+.residual <- function(x, y, n, pars, scale = 0.07, family = c("normal", "Cauchy"), trunc = FALSE) {
   family <- match.arg(family)
-  Cauchy_flag = (family == "Cauchy")
+  Cauchy_flag = (family == "Cauchy") # Why?!
   if (Cauchy_flag == FALSE) {
-    # return(sum((.Hill(x, pars) - y) ^ 2))
     diffs <- .Hill(x, pars)-y
     if (trunc == FALSE) {
-      return(sum(-log(.dmednnormals(diffs, n, scale))))
+      return(sum(-log(CoreGx::.dmednnormals(diffs, n, scale))))
     } else {
       down_truncated <- abs(y) >= 1
       up_truncated <- abs(y) <= 0
@@ -163,15 +172,14 @@
       # function becomes discrete
       # For down_truncated, 1-cdf(diffs) = cdf(-diffs)
 
-      return(sum(-log(.dmednnormals(diffs[!(down_truncated | up_truncated)], n, scale))) + sum(-log(.edmednnormals(-diffs[up_truncated | down_truncated], n, scale))))
+      return(sum(-log(CoreGx::.dmednnormals(diffs[!(down_truncated | up_truncated)], n, scale))) + sum(-log(CoreGx::.edmednnormals(-diffs[up_truncated | down_truncated], n, scale))))
 
     }
 
   } else {
     diffs <- .Hill(x, pars)-y
     if (trunc == FALSE) {
-      # return(sum(-log(6 * scale / (pi * (scale ^ 2 + diffs ^ 2)) * (1 / 2 + 1 / pi * atan(diffs / scale)) * (1 / 2 - 1 / pi * atan(diffs / scale)))))
-      return(sum(-log(.dmedncauchys(diffs, n, scale))))
+      return(sum(-log(CoreGx::.dmedncauchys(diffs, n, scale))))
     } else {
       down_truncated <- abs(y) >= 1
       up_truncated <- abs(y) <= 0
@@ -180,17 +188,15 @@
       # function becomes discrete
       # For down_truncated, 1-cdf(diffs) = cdf(-diffs)
 
-      return(sum(-log(.dmedncauchys(diffs[!(down_truncated | up_truncated)], n, scale))) + sum(-log(.edmedncauchys(-diffs[up_truncated | down_truncated], n, scale))))
-
-      # return(sum(log(6 * scale / (pi * (scale ^ 2 + diffs ^ 2)) * (1 / 2 + 1 / pi * atan(diffs[setdiff(1:length(y), union(down_truncated, up_truncated))] / scale))
-      # * (1 / 2 - 1 / pi * atan(diffs[setdiff(1:length(y), union(down_truncated, up_truncated))] / scale))),
-      # -log(1 / 2 - 3 / (2 * pi) * atan((1 - diffs[down_truncated] - y[down_truncated]) / scale) + 2 / pi ^ 3 * (atan((1 - diffs[down_truncated] - y[down_truncated]) / scale)) ^ 3),
-      # -log(-1 / 2 + 3 / (2 * pi) * atan((-diffs[up_truncated] - y[up_truncated]) / scale) - 2 / pi ^ 3 * (atan((- diffs[up_truncated] - y[up_truncated]) / scale)) ^ 3)))
+      return(sum(-log(CoreGx::.dmedncauchys(diffs[!(down_truncated | up_truncated)], n, scale))) + sum(-log(CoreGx::.edmedncauchys(-diffs[up_truncated | down_truncated], n, scale))))
     }
   }
 }
 
-## generate an initial guess for dose-response curve parameters by evaluating the residuals at different lattice points of the search space
+## generate an initial guess for dose-response curve parameters by evaluating
+## the residuals at different lattice points of the search space
+## FIXME:: Why is this different from CoreGx?
+## FIXME:: Is this the same as PharmacoGx?
 .meshEval<-function(log_conc,
                     viability,
                     lower_bounds = c(0, 0, -6),
@@ -237,13 +243,7 @@
   return(guess)
 }
 
-## get vector of interpolated concentrations for graphing purposes
-.GetSupportVec <- function(x, output_length = 1001) {
-  return(seq(from = min(x), to = max(x), length.out = output_length))
-}
 ######## TODO ADD computationg from  being passed in params
-
-
 #  Fits dose-response curves to data given by the user
 #  and returns the AUC of the fitted curve, normalized to the length of the concentration range.
 #
@@ -257,48 +257,6 @@
 #  curve-fitting is performed.
 .computeAUCUnderFittedCurve <- function(concentration, viability, trunc=TRUE, verbose=FALSE) {
 
-  # #CHECK THAT FUNCTION INPUTS ARE APPROPRIATE
-  # if (prod(is.finite(conc)) != 1) {
-  #   print(conc)
-  #   stop("Concentration vector contains elements which are not real numbers.")
-  # }
-
-  # if (prod(is.finite(viability)) != 1) {
-  #   print(viability)
-  #   stop("Viability vector contains elements which are not real numbers.")
-  # }
-
-  # if (is.logical(trunc) == FALSE) {
-  #   print(trunc)
-  #   stop("'trunc' is not a logical.")
-  # }
-
-  # if (length(conc) != length(viability)) {
-  #   print(conc)
-  #   print(viability)
-  #   stop("Concentration vector is not of same length as viability vector.")
-  # }
-
-  # if (min(conc) < 0) {
-  #   stop("Concentration vector contains negative data.")
-  # }
-
-  # if (min(viability) < 0 && verbose) {
-  #   warning("Warning: Negative viability data.")
-  # }
-
-  # if (max(viability) > 100 && verbose) {
-  #   warning("Warning: Viability data exceeds negative control.")
-  # }
-
-  # #CONVERT DOSE-RESPONSE DATA TO APPROPRIATE INTERNAL REPRESENTATION
-  # log_conc <- log10(conc)
-  # viability <- viability / 100
-
-  # if (trunc == TRUE) {
-  #   viability[which(viability < 0)] <- 0
-  #   viability[which(viability > 1)] <- 1
-  # }
   log_conc <- concentration
   #FIT CURVE AND CALCULATE IC50
   pars <- unlist(logLogisticRegression(log_conc,
@@ -306,7 +264,7 @@
                                        conc_as_log = TRUE,
                                        viability_as_pct = FALSE,
                                        trunc = trunc))
-  x <- .GetSupportVec(log_conc)
+  x <- CoreGx::.getSupportVec(log_conc)
   return(1 - trapz(x, .Hill(x, pars)) / (log_conc[length(log_conc)] - log_conc[1]))
 }
 #This function is being used in computeSlope
@@ -316,8 +274,7 @@
   return(beta1)
 }
 
-updateMaxConc <- function(pSet){
-
-  pSet@sensitivity$info$max.conc <- apply(pSet@sensitivity$raw[,,"Dose"], 1, max, na.rm=TRUE)
-  return(pSet)
+updateMaxConc <- function(tSet) {
+  sensitivityInfo(tSet)$max.conc <- apply(sensitivityRaw(tSet)[,,"Dose"], 1, max, na.rm=TRUE)
+  return(tSet)
 }
