@@ -9,8 +9,8 @@
 #'
 #' if (interactive()) {
 #'   drugGeneResponseCurve(TGGATESsmall, dose = c("Control", "Low", "Middle"),
-#'   mDataTypes="rna", drug = drugNames(TGGATESsmall)[1],
-#'   duration = c("2", "8", "24"), features = "ENSG00000000003_at")
+#'   mDataTypes="rna", drug = treatmentNames(TGGATESsmall)[1],
+#'   duration = c("2", "8", "24"), features = "ENSG00000002726_at")
 #' }
 #'
 #' @param tSet \code{ToxicoSet} A ToxicoSet to be plotted in this graph. Currently
@@ -22,30 +22,34 @@
 #'   include in this plot. Defaults to the first mDataType if not specified.ex
 #'   This release version only accepts one mDataType, more to be added in
 #'   forthcoming releases.
-#' @param features \code{character} A vector of feature names to include in the plot.
-#'   If you specify more than two dose levels, you may only pass in up to two features.
+#' @param features \code{character} A vector of feature names to include in the
+#'   plot. If you specify more than two dose levels, you may only pass in up to
+#'   two features.
 #' @param drug \code{character} A drug name to include in this plot.
-#'   See drugNames(tSet) for a list of options.
+#'   See treatmentNames(tSet) for a list of options.
 #' @param duration \code{character} A vector of durations to include in the plot.
 #' @param summarize_replicates \code{logical} If TRUE will average viability
 #'   across replicates for each unique drug-dose-duration combination.
-#' @param cell_lines \code{character} A vector of cell lines to include in the plot.
+#' @param cell_lines \code{character} A vector of cell lines to include in the
+#'   plot.
 #' @param line_width \code{numeric} A number specifying the thickness of lines
 #'   in the plot, as passed to size in geom_line(). Defaults to 1.
 #' @param point_size \code{numeric} A number specifying how large points should
 #'   be in the plot, as passed to size in geom_point(). Defaults to 2.5.
-#' @param ggplot_args \code{list} A list of ggplot2 functions which can be called using the plot + function()
-#'   syntax. This allows arbitrary customization of the plot including changing the title, axis labels, colours, etc.
-#'   Please see the included examples for basic usage or ggplot2 documentation for advanced customization.
+#' @param ggplot_args \code{list} A list of ggplot2 functions which can be
+#'   called using the plot + function() syntax. This allows arbitrary
+#'   customization of the plot including changing the title, axis labels,
+#'   colours, etc. Please see the included examples for basic usage or ggplot2
+#'   documentation for advanced customization.
 #' @param verbose \code{boolean} Should warning messages about the data passed
 #'   in be printed?
 #'
 #' @return Plot of the viabilities for each drug vs time of exposure
 #'
-#' @import data.table
+#' @importFrom data.table data.table melt.data.table `:=`
 #' @import ggplot2
 #' @importFrom tibble as_tibble
-
+#'
 #' @export
 drugGeneResponseCurve <- function(
   tSet,
@@ -73,12 +77,12 @@ drugGeneResponseCurve <- function(
   if (length(dose) > 2) { if (length(features) > 2) { stop("To plot more than one dose level, please specify up to two molecular feature...")}}
 
   # Deal with controls (i.e., treated with DMSO)
-  if (any(vapply(tSet, function(tSet) { names(tSet) == "drugMatrix"}, FUN.VALUE = logical(1)))) {
+  if (any(vapply(tSet, function(tSet) { name(tSet) %in% c("drugMatrix_rat", "EMEXP2458")}, FUN.VALUE = logical(1)))) {
     drug <- c("DMSO", drug)
   }
 
   ## TODO:: Generalize this to work with multiple data types
-  if (missing(mDataTypes)) { mDataTypes <- names(tSet[[1]]@molecularProfiles) }
+  if (missing(mDataTypes)) { mDataTypes <- names(molecularProfilesSlot(tSet[[1]])) }
 
   if (is.null(features)) {
     features <- lapply(tSet, function(tSet) {
@@ -86,19 +90,19 @@ drugGeneResponseCurve <- function(
     })
   }
 
-  if (missing(cell_lines)) {cell_lines <- unique(phenoInfo(tSet[[1]], mDataTypes[1])$cellid)}
+  if (missing(cell_lines)) {cell_lines <- unique(phenoInfo(tSet[[1]], mDataTypes[1])$sampleid)}
   if (length(cell_lines) > 1) { stop("Only one cell type per plot is currently supported...")}
 
   # Places features in list if not already
   if (!is(features, "list")) {
     features <- list(features)
   }
-  names(features) <- vapply(tSet, function(x) names(x), FUN.VALUE = character(1))
+  names(features) <- vapply(tSet, function(x) name(x), FUN.VALUE = character(1))
 
   # Subsetting the tSet based on parameter arguments
   tSet <- lapply(tSet, function(tSet) {
     suppressWarnings({ToxicoGx::subsetTo(tSet, mDataType = mDataTypes, drugs = drug,
-                       duration = duration, features = unique(unlist(features)))})
+                       duration = duration, features = unique(unlist(features)), cell_lines=unique(cell_lines))})
   })
 
   # Get only the dose levels available for that drug
@@ -113,25 +117,25 @@ drugGeneResponseCurve <- function(
           mProf,
           keep.rownames = TRUE
         ),
-        "pInfo" = data.table(phenoInfo(tSet, mDataType))
+        "pInfo" = data.table(as.data.frame(phenoInfo(tSet, mDataType)))
       )
     })
     names(m) <- mDataTypes; m
   })
-  names(plotData) <-  vapply(tSet, function(x) names(x), FUN.VALUE = character(1))
+  names(plotData) <-  vapply(tSet, function(x) name(x), FUN.VALUE = character(1))
 
   #### Assembling the plot data ####
   d <- plotData[[1]][[1]]$data
   pInfo <- plotData[[1]][[1]]$pInfo
   data <- melt.data.table(d, id.vars = 1, variable.factor = FALSE)
   colnames(data) <- c("feature", "samplename", "expression")
-  data[, samplename := as.numeric(samplename)]
-  pInfo[, samplename := as.numeric(samplename)]
-  fInfo <- data.table(featureInfo(tSet[[1]], "rna"))
+  if (is.numeric(data$samplename)) data[, samplename := as.character(samplename)]
+  if (is.numeric(pInfo$samplename)) pInfo[, samplename := as.character(samplename)]
+  fInfo <- data.table(as.data.frame(featureInfo(tSet[[1]], "rna")))
   colnames(fInfo)[2] <- "feature"
 
   plotData <- merge(data, pInfo[, .(samplename, individual_id,
-                                    drugid, dose_level, duration)],
+                                    treatmentid, dose_level, duration)],
                     by = "samplename")
   plotData <- merge(plotData, fInfo[, .(Symbol, feature)], by = "feature")
   plotData[, dose_level := as.factor(dose_level)]
@@ -147,7 +151,7 @@ drugGeneResponseCurve <- function(
     plot <- ggplot(as_tibble(plotData),
            aes(x = as.numeric(duration),
                y = expression,
-               color = dose_level,
+               color = factor(dose_level, levels=dose),
                linetype = as.factor(individual_id),
                shape = Symbol,
                group = interaction(dose_level, individual_id, Symbol))) +
@@ -155,7 +159,10 @@ drugGeneResponseCurve <- function(
       geom_point(size = point_size)
   } else {
     plotData <- plotData[, expression := mean(expression), by = .(dose_level, duration, Symbol)][individual_id == 1]
-    plot <- ggplot(plotData, aes(as.numeric(duration), expression, color = dose_level,)) +
+    plot <- ggplot(plotData,
+                   aes(as.numeric(duration),
+                       expression,
+                       color = factor(dose_level, levels=c("Control", "Low", "Middle", "High")))) +
       geom_line(aes(linetype = Symbol), size = line_width) +
       geom_point(size = point_size)
   }
