@@ -17,8 +17,7 @@
 #' @examples
 #' if (interactive()) {
 #' data(TGGATESsmall)
-#' drug.perturbation <- drugPerturbationSig(TGGATESsmall, mDataType="rna",
-#'  features = head(fNames(TGGATESsmall, "rna")), nthread=1)
+#' drug.perturbation <- drugPerturbationSig(TGGATESsmall, mDataType="rna", features = head(fNames(TGGATESsmall, "rna")), nthread=1)
 #' }
 #'
 #' @param tSet \code{ToxicoSet} a ToxicoSet of the perturbation experiment type
@@ -58,13 +57,15 @@ drugPerturbationSig <- function(
   returnValues=c("estimate","tstat", "pvalue", "fdr"),
   verbose=FALSE
 ){
-
   # ALLOCATE CORES FOR PARALLEL PROCESSING
   availcore <- parallel::detectCores()
   if ( nthread > availcore) {
     nthread <- availcore
   }
-  options("mc.cores" = nthread)
+  # Set multicore options
+  op <- options()
+  options(mc.cores=nthread)
+  on.exit(options(op))
 
   ## MISSING VALUE HANDLING FOR PARAMETERS
   # Get named list of defualt values for missing parameters
@@ -80,6 +81,9 @@ drugPerturbationSig <- function(
     }
   }
 
+  ##TODO:: Fix variable names output from paramMissingHandler
+  if ('durations' %in% ls()) { duration <- durations }
+
   # ERROR HANDLING FOR PARAMETERS
   paramErrorChecker("drugPerturbationSig", tSet = tSet,
                     mDataType = mDataType, cell_lines = cell_lines,
@@ -88,20 +92,33 @@ drugPerturbationSig <- function(
 
   returnValues <- match.arg(returnValues, several.ok = TRUE)
 
+  # Add DMSO for the drugMatrix
+  if (name(tSet) %in% c('drugMatrix_rat', 'EMEXP2458')) {
+    if (!('DMSO' %in% drugs)) {
+      drugs <- c('DMSO', drugs)
+    }
+    if (!('Control' %in% dose)) {
+      dose <- c('Control', dose)
+    }
+  }
+
   # SUBSET tSET BASED ON PARAMETERS
   tSetSubsetOnParams <-
-    suppressWarnings(subsetTo(tSet, mDataType = mDataType, cells = cell_lines, drugs = drugs,
-             features = features, duration = duration))
+    suppressWarnings(subsetTo(tSet, mDataType = mDataType, cells = cell_lines, drugs = drugs, features = features, duration = duration))
 
   # SUBSET SAMPLES BASED ON DOSE
-  samples <- rownames(phenoInfo(tSetSubsetOnParams, mDataType)[which(phenoInfo(tSetSubsetOnParams, mDataType)$dose %in% dose),])
+  samples <- rownames(phenoInfo(tSetSubsetOnParams, mDataType)[which(phenoInfo(tSetSubsetOnParams, mDataType)$dose_level %in% dose),])
 
   # LOOP OVER DRUGS TO CALCULATE PER DRUG SUMMARY STATISTICS
-  mcres <- lapply(drugs, function(x, exprs, sampleinfo) {
+  mcres <- lapply(drugs[drugs != 'DMSO'], function(x, exprs, sampleinfo) {
 
+    # Add DMSO for the drugMatrix since it is the only control
+    if (name(tSet) %in% c('drugMatrix_rat', 'EMEXP2458')) {
+        x <- c('DMSO', x)
+    }
     # Subset to correct drugs
-    exprs <- exprs[which(sampleinfo[ , "drugid"] %in% x),]
-    sampleinfo <- sampleinfo[which(sampleinfo[ , "drugid"] %in% x),]
+    exprs <- exprs[which(sampleinfo[ , "treatmentid"] %in% x),]
+    sampleinfo <- sampleinfo[which(sampleinfo[ , "treatmentid"] %in% x),]
 
     # Warning that rankGeneDrugPerturbation will return a matrix of NAs for this drug
     if (length(unique(as.character(sampleinfo[, "xptype"]))) < 2) {
@@ -111,13 +128,13 @@ drugPerturbationSig <- function(
                      Adding another dose level will likely generate results."))
     }
     res <- NULL
-    i <- x
+    i <- x[x != 'DMSO']
 
     ## using a linear model (x ~ concentration + cell + batch + duration)
-    res <- ToxicoGx::rankGeneDrugPerturbation(
-      data = exprs, drug = x, drug.id = as.character(sampleinfo[ , "drugid"]),
+    res <- rankGeneDrugPerturbation(
+      data = exprs, drug = x, drug.id = as.character(sampleinfo[ , "treatmentid"]),
       drug.concentration = as.numeric(sampleinfo[ , "concentration"]),
-      type = as.character(sampleinfo[ , "cellid"]),
+      type = as.character(sampleinfo[ , "sampleid"]),
       xp = as.character(sampleinfo[ , "xptype"]),
       batch = as.character(sampleinfo[ , "batchid"]),
       duration = as.character(sampleinfo[ , "duration"]) ,
@@ -126,25 +143,26 @@ drugPerturbationSig <- function(
     res <- list(res)
     names(res) <- i
     return(res)
-  }, exprs = t(molecularProfiles(tSetSubsetOnParams, mDataType)[features, samples, drop=FALSE]),
-     sampleinfo = phenoInfo(tSetSubsetOnParams, mDataType)[which(phenoInfo(tSetSubsetOnParams, mDataType)$samplename %in% samples), ]
+  }, exprs = t(as.data.frame(molecularProfiles(tSetSubsetOnParams, mDataType)[features, samples, drop=FALSE])),
+     sampleinfo = as.data.frame(phenoInfo(tSetSubsetOnParams, mDataType)[which(phenoInfo(tSetSubsetOnParams, mDataType)$samplename %in% samples), ])
   )
 
   # ASSEMBLE RESULTS TO BE INCLUDED IN TOXICOSIG OBJECT
   res <- do.call(c, mcres)
-  res <- res[!sapply(res, is.null)]
+  res <- res[!vapply(res, is.null, FUN.VALUE=logical(1))]
   drug.perturbation <- array(NA, dim = c(nrow(featureInfo(tSet, mDataType)[features,, drop = FALSE]), length(res), ncol(res[[1]])), dimnames = list(rownames(featureInfo(tSet, mDataType)[features,,drop = FALSE]), names(res), colnames(res[[1]])))
   for (j in seq_len(ncol(res[[1]]))) {
-    ttt <- sapply(res, function(x, j, k) {
+    ttt <- vapply(res, function(x, j, k) {
       xx <- array(NA, dim = length(k), dimnames = list(k))
       xx[rownames(x)] <- x[ , j, drop = FALSE]
       return(xx)
-    }, j = j, k = rownames(featureInfo(tSet, mDataType)[features,, drop = FALSE]))
+    }, j = j, k = rownames(featureInfo(tSet, mDataType)[features,, drop = FALSE]),
+    FUN.VALUE=numeric(dim(drug.perturbation)[1]))
     drug.perturbation[rownames(featureInfo(tSet, mDataType)[features,, drop = FALSE]), names(res), j] <- ttt
   }
 
   # CREATE TOXICOSIG OBJECT
-  drug.perturbation <- ToxicoGx::ToxicoSig(drug.perturbation, tSetName = cSetName(tSet), Call = as.character(match.call()), SigType = 'Perturbation')
+  drug.perturbation <- ToxicoGx::ToxicoSig(drug.perturbation, tSetName = name(tSet), Call = as.character(match.call()), SigType = 'Perturbation')
 
   # RETURN TOXICOSIG OBJECT
   return(drug.perturbation)
