@@ -9,7 +9,7 @@
 #'
 #'   # Default settings
 #'   plot <- drugTimeResponseCurve(TGGATESsmall, cell_lines = "Hepatocyte",
-#'   dose = c("Control", "Low", "Middle"), drugs = drugNames(TGGATESsmall)[6],
+#'   dose = c("Control", "Low", "Middle"), drugs = treatmentNames(TGGATESsmall)[6],
 #'   duration = c("2", "8", "24"))
 #'
 #'   # Customize title, x/y labels, x/y limits, colour palette and define
@@ -24,7 +24,7 @@
 #'    if(interactive()) {
 #'       drugTimeResponseCurve(TGGATESsmall, cell_lines = "Hepatocyte",
 #'         dose = c("Control", "Low", "Middle"),
-#'         drugs = drugNames(TGGATESsmall)[6], duration = c("2", "8", "24"),
+#'         drugs = treatmentNames(TGGATESsmall)[6], duration = c("2", "8", "24"),
 #'         ggplot_args = customizations)
 #'    }
 #'
@@ -101,7 +101,7 @@ drugTimeResponseCurve <- function(
   # Gather data for the plot
   plotData <- lapply(tSet, function(tSet) {
     sInfo <- sensitivityInfo(tSet)[, seq_len(4)]
-    sValues <- tSet@sensitivity$raw[,,2]
+    sValues <- sensitivityRaw(tSet)[,,2]
     plotData <- cbind(sInfo, sValues)
     cols <- c('Low', 'Middle', 'High')
     colnames(plotData)[which(colnames(plotData) %in% c('doses1', 'doses2', 'doses3'))] <-
