@@ -2,10 +2,11 @@
 #' @importFrom stats complete.cases
 #' @importFrom stats p.adjust
 
+##TODO:: Convert this to roxygen2 format
 #################################################
 ## Rank genes based on drug effect in the Connectivity Map
 ##
-## inputs:    
+## inputs:
 ##      - data: gene expression data matrix
 ##            - drugpheno: sensititivity values fo thr drug of interest
 ##            - type: cell or tissue type for each experiment
@@ -20,19 +21,25 @@
 ## Notes:    duration is not taken into account as only 4 perturbations lasted 12h, the other 6096 lasted 6h
 #################################################
 
-rankGeneDrugSensitivity <- function (data, drugpheno, type, batch, single.type=FALSE, standardize = "SD", nthread=1, verbose=FALSE) {
+rankGeneDrugSensitivity <- function (data, drugpheno, type, batch,
+                                     single.type=FALSE, standardize = "SD",
+                                     nthread=1, verbose=FALSE) {
   if (nthread != 1) {
     availcore <- parallel::detectCores()
     if (missing(nthread) || nthread < 1 || nthread > availcore) {
       nthread <- availcore
     }
   }
+  # Set multicore options
+  op <- options()
+  options(mc.cores=nthread)
+  on.exit(options(op))
 
   if(is.null(dim(drugpheno))){
 
     drugpheno <- data.frame(drugpheno)
 
-  } else if(class(drugpheno)!="data.frame"){
+  } else if(!is(drugpheno, "data.frame")) {
     drugpheno <- as.data.frame(drugpheno)
 
   }
@@ -47,7 +54,7 @@ rankGeneDrugSensitivity <- function (data, drugpheno, type, batch, single.type=F
     stop("length of drugpheno, type, duration, and batch should be equal to the number of rows of data!")
   }
   rownames(drugpheno) <- names(type) <- names(batch) <- rownames(data)
-  
+
   res <- NULL
   utype <- sort(unique(as.character(type)))
   ltype <- list("all"=utype)
@@ -58,12 +65,10 @@ rankGeneDrugSensitivity <- function (data, drugpheno, type, batch, single.type=F
   res <- NULL
   ccix <- complete.cases(data, type, batch, drugpheno)
   nn <- sum(ccix)
-#  nc <- c("estimate", "se", "n", "tstat", "fstat", "pvalue", "fdr")
-#  nc <- c("estimate", "se", "n", "pvalue", "fdr")
   if(!any(unlist(lapply(drugpheno,is.factor)))){
      if(ncol(drugpheno)>1){
-      ##### FIX NAMES!!!
-      nc <- lapply(1:ncol(drugpheno), function(i){
+      ##FIXME:: NAMES!
+      nc <- lapply(seq_len(ncol(drugpheno)), function(i){
 
         est <- paste("estimate", i, sep=".")
         se <-  paste("se", i, sep=".")
@@ -73,24 +78,18 @@ rankGeneDrugSensitivity <- function (data, drugpheno, type, batch, single.type=F
         return(nc)
 
       })
-      #nc <- do.call(c, rest)
       nc  <- c(nc, n=nn, "fstat"=NA, "pvalue"=NA, "fdr")
     } else {
       nc  <- c("estimate", "se", "n", "tstat", "fstat", "pvalue", "df", "fdr")
     }
   } else {
     nc  <- c("estimate", "se", "n", "pvalue", "fdr")
-  }  
-    
+  }
 
-  
-  for (ll in 1:length(ltype)) {
+
+
+  for (ll in seq_along(ltype)) {
     iix <- !is.na(type) & is.element(type, ltype[[ll]])
-    # ccix <- complete.cases(data[iix, , drop=FALSE], drugpheno[iix,,drop=FALSE], type[iix], batch[iix]) ### HACK???
-    
-    # ccix <- sapply(seq_len(NROW(data[iix,,drop=FALSE])), function(x) {
-    #   return(any(!is.na(data[iix,,drop=FALSE][x,])) && any(!is.na(drugpheno[iix,,drop=FALSE][x,])) && any(!is.na(type[iix][x])) && any(!is.na(batch[iix][x])))
-    # })
 
     data.not.all.na <- apply(data[iix,,drop=FALSE], 1, function(x) {
       any(!is.na(x))
@@ -98,12 +97,12 @@ rankGeneDrugSensitivity <- function (data, drugpheno, type, batch, single.type=F
     drugpheno.not.all.na <- apply(drugpheno[iix,,drop=FALSE], 1, function(x) {
       any(!is.na(x))
     })
-    type.not.all.na <- sapply(type[iix], function(x) {
+    type.not.all.na <- vapply(type[iix], function(x) {
       !is.na(x)
-    })
-    batch.not.all.na <- sapply(batch[iix], function(x) {
+    }, FUN.VALUE=logical(1))
+    batch.not.all.na <- vapply(batch[iix], function(x) {
       !is.na(x)
-    })
+    }, FUN.VALUE=logical(1))
 
     ccix <- data.not.all.na & drugpheno.not.all.na & type.not.all.na & batch.not.all.na
 
@@ -115,19 +114,17 @@ rankGeneDrugSensitivity <- function (data, drugpheno, type, batch, single.type=F
       res <- c(res, rest)
     } else {
       splitix <- parallel::splitIndices(nx=ncol(data), ncl=nthread)
-      splitix <- splitix[sapply(splitix, length) > 0]
-      mcres <- parallel::mclapply(splitix, function(x, data, type, batch, drugpheno, standardize) {
+      ##TODO:: Can we reimpement this without length?
+      splitix <- splitix[vapply(splitix, length, FUN.VALUE=numeric(1)) > 0]
+      mcres <- BiocParallel::bplapply(splitix, function(x, data, type, batch, drugpheno, standardize) {
         res <- t(apply(data[ , x, drop=FALSE], 2, geneDrugSensitivity, type=type, batch=batch, drugpheno=drugpheno, verbose=verbose, standardize=standardize))
         return(res)
-      }, data=data[iix, , drop=FALSE], type=type[iix], batch=batch[iix], drugpheno=drugpheno[iix,,drop=FALSE], standardize=standardize, mc.cores=nthread)
+      }, data=data[iix, , drop=FALSE], type=type[iix], batch=batch[iix], drugpheno=drugpheno[iix,,drop=FALSE], standardize=standardize)
       rest <- do.call(rbind, mcres)
       rest <- cbind(rest, "fdr"=p.adjust(rest[ , "pvalue"], method="fdr"))
-      # rest <- rest[ , nc, drop=FALSE]
       res <- c(res, list(rest))
     }
   }
   names(res) <- names(ltype)
   return(res)
-}
-
-## End
+}
\ No newline at end of file
