@@ -10,14 +10,14 @@
 #' data(TGGATESsmall)
 #' summMP <- ToxicoGx::summarizeMolecularProfiles(
 #'   tSet = TGGATESsmall, mDataType = "rna",
-#'   cell_lines=cellNames(TGGATESsmall), drugs = head(drugNames(TGGATESsmall)),
-#'   features = fNames(TGGATESsmall,"rna")[1:100], duration = "8",
+#'   cell_lines=sampleNames(TGGATESsmall), drugs = head(treatmentNames(TGGATESsmall)),
+#'   features = fNames(TGGATESsmall,"rna")[seq_len(100)], duration = "8",
 #'   dose = c("Control", "High"), summary.stat = "median",
 #'   fill.missing = TRUE, verbose=TRUE
 #'   )
 #'
 #' #subset into expression matrix for a requested drug
-#' assays <- SummarizedExperiment::assays(summMP)[[drugNames(TGGATESsmall)[1]]]
+#' assays <- SummarizedExperiment::assays(summMP)[[treatmentNames(TGGATESsmall)[1]]]
 #' #summarization of phenoData for requested experiments
 #' phenoData <- SummarizedExperiment::colData(summMP)
 #' #summarization of phenoData for requested experiments
@@ -93,31 +93,29 @@ summarizeMolecularProfiles <-
 
     ##### FUNCTION LOGIC BEGINS #####
 
-    dd <- ToxicoGx::molecularProfiles(tSet, mDataType)[features, , drop = F] #expression matrix of the tSet
+    dd <- ToxicoGx::molecularProfiles(tSet, mDataType)[features, , drop = FALSE] #expression matrix of the tSet
     pp <- ToxicoGx::phenoInfo(tSet, mDataType) #phenoData of the tSet
-    ff <- ToxicoGx::featureInfo(tSet, mDataType)[features,,drop = F]
+    ff <- ToxicoGx::featureInfo(tSet, mDataType)[features,,drop = FALSE]
 
     unique.cells <- unique(cell_lines) #unique cell types (row names of the result)
     #subset phenoData to include only the experiments requested
-    pp2 <- pp[(pp[,"cellid"] %in% unique.cells & pp[,"drugid"] %in% drugs
-               & pp[,"duration"] %in% duration & pp[,"dose_level"] %in% dose), , drop = F] #only the phenoData that is relevant to the request input
-    dd2 <- dd[features,rownames(pp2), drop = F] #only the gene expression data that is relevant to the request input
+    pp2 <- pp[(pp[,"sampleid"] %in% unique.cells & pp[,"treatmentid"] %in% drugs
+               & pp[,"duration"] %in% duration & pp[,"dose_level"] %in% dose), , drop = FALSE] #only the phenoData that is relevant to the request input
+    dd2 <- dd[features,rownames(pp2), drop = FALSE] #only the gene expression data that is relevant to the request input
 
     #vector of experimental conditions requested for each drug
     a <- paste(expand.grid(dose,duration)[,1], expand.grid(dose, duration)[,2], sep = ";")
-    #b <- expand.grid(dose,duration)
 
-    ddt <- dd[,NA][,c(1:length(a)), drop = F]
+    ##TODO:: Do we really need this c() wrapper around seq_along()?
+    ddt <- dd[,NA][,c(seq_along(a)), drop = FALSE]
     ppt <- pp[FALSE,]
 
     exp.list <- list()
     cnt <- 0
-    blank <- ddt[,1,drop = F]
+    blank <- ddt[,1,drop = FALSE]
 
-    #lapply(drugs, function(drug){
     for (drug in drugs) {
       cnt <- cnt + 1
-      #lapply(a, function(i){
       for (i in a) {
         if (verbose == TRUE) {
           message(i)
@@ -128,8 +126,8 @@ summarizeMolecularProfiles <-
 
         pp3 <- pp2[(pp2[,"dose_level"] == curr_dose
                     & pp2[,"duration"] == curr_dur
-                    & pp2[,"drugid"] == drug), , drop = F]
-        dd3 <- dd2[features,rownames(pp3), drop = F]
+                    & pp2[,"treatmentid"] == drug), , drop = FALSE]
+        dd3 <- dd2[features,rownames(pp3), drop = FALSE]
 
         if (ncol(dd3) > 1){ #if there are replicates
           switch(summary.stat, #ddr, ppr contains gene expression data, phenoData, for replicates
@@ -149,40 +147,36 @@ summarizeMolecularProfiles <-
           ppt <- rbind(ppt,ppr)
         } else if (ncol(dd3) == 0){ #experiment does not exist
           ddt <- cbind(ddt,blank)
-          # ppt <- rbind(ppt,pp3[NA,])
         }
         else{#no replicates
           ddt <- cbind(ddt,dd3)
           ppt <- rbind(ppt,pp3)
         }
-      }#)
-      ddt <- ddt[,-(seq_len(length(a))), drop = F] #ddt contains the final expression matrix for a single drug
+      }
+      ddt <- ddt[,-(seq_len(length(a))), drop = FALSE] #ddt contains the final expression matrix for a single drug
       colnames(ddt) <- a
 
       exp.list[[cnt]] <- ddt
-    }#)
+    }
     names(exp.list) <- drugs
     ppf <- pp2[FALSE,]
-    #lapply(unique(ppt[,"dose_level"]), function(i){
     for (i in unique(ppt[,"dose_level"])) {
       if (verbose == TRUE ) {
         message(i)
       }
-      #lapply(unique(ppt[,"duration"]), function(j){
       for (j in unique(ppt[,"duration"])) {
         if (verbose == TRUE) {
           message(j)
         }
-        pp4 <- apply(ppt[ppt[,"dose_level"] == i & ppt[,"duration"] == j,,drop = F], 2, function(x) {
+        pp4 <- apply(ppt[ppt[,"dose_level"] == i & ppt[,"duration"] == j,,drop = FALSE], 2, function(x) {
           x <- paste(unique(as.character(x[!is.na(x)])), collapse = "///")
-          #if (is.na(x)){x <- paste("Exp ",,sep="")}
           return(x)
         })
         pp4 <- as.data.frame(t(pp4))
         pp4[!is.na(pp4) & pp4 == ""] <- NA
         ppf <- rbind(ppf,pp4)
-      }#)
-    }#)
+      }
+    }
     ppf <- as.data.frame(ppf,stringsAsFactors=FALSE)
     rownames(ppf) <- paste(ppf[,"dose_level"],";",ppf[,"duration"], sep = "")
     vec <- as.vector(colnames(exp.list[[1]]))
